@@ -78,17 +78,19 @@ public:
 
   void PreInit()
   {
-    Lum::Combo  *combo;
-    Lum::Panel  *vert;
+    Lum::Def::OneOfMany setChoiceDef(Lum::Def::Desc(L"Dice Set"),
+                                     currentSet,setsModel);
+
+    Lum::Object         *setChoice;
+    Lum::Panel          *vert;
 
     vert=Lum::VPanel::Create(true,true);
 
-    combo=new Lum::IndexCombo();
-    combo->SetMinWidth(Lum::Base::Size::stdCharWidth,20);
-    combo->SetFlex(true,false);
-    combo->SetTableModel(setsModel);
-    combo->SetModel(currentSet);
-    vert->Add(combo);
+    setChoice=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(setChoiceDef);
+    setChoice->SetFlex(true,false);
+    setChoice->SetMinWidth(Lum::Base::Size::stdCharWidth,20);
+
+    vert->Add(setChoice);
 
     vert->AddSpace();
     vert->Add(Lum::HPanel::Create(true,true)
